class Arturo < Formula
  desc "Simple, modern and portable programming language for efficient scripting"
  homepage "https://arturo-lang.io/"
  url "https://github.com/arturo-lang/arturo/archive/refs/tags/v0.9.83.tar.gz"
  sha256 "0bb3632f21a1556167fdcb82170c29665350beb44f15b4666b4e22a23c2063cf"
  license "MIT"

  depends_on "gmp"
  depends_on "mpfr"

  # TODO: switch to `depends_on "nim" => :build` in the next release
  resource "nim" do
    url "https://nim-lang.org/download/nim-1.6.14.tar.xz"
    sha256 "d070d2f28ae2400df7fe4a49eceb9f45cd539906b107481856a0af7a8fa82dc9"
  end

  # Workaround for newer Clang
  # upstream pr ref, https://github.com/arturo-lang/arturo/pull/1635
  patch :DATA

  def install
    (buildpath/"nim").install resource("nim")
    cd "nim" do
      system "./build.sh"
      system "./bin/nim", "c", "-d:release", "koch"
      system "./koch", "boot", "-d:release", "-d:useLinenoise"
    end
    ENV.prepend_path "PATH", buildpath/"nim/bin"

    inreplace "build.nims", /ROOT_DIR\s*=\s*r"\{getHomeDir\(\)\}.arturo".fmt/, "ROOT_DIR=\"#{prefix}\""

    # Work around issues with Xcode 14.3
    # @mhelpers@swebviews.nim.c:1116:2: error: call to undeclared function 'generateDefaultMainMenu';
    # ISO C99 and later do not support implicit function declarations
    inreplace "build.nims", "--passC:'-flto'", "--passC:'-flto' --passC:'-Wno-implicit-function-declaration'"

    # Use mini install on Linux to avoid webkit2gtk dependency, which does not have a formula.
    args = ["log", "release"]
    args << "mini" if OS.linux?
    system "./build.nims", "install", *args
  end

  test do
    (testpath/"hello.art").write <<~EOS
      print "hello"
    EOS
    assert_equal "hello", shell_output("#{bin}/arturo #{testpath}/hello.art").chomp
  end
end

__END__
diff --git a/build.nims b/build.nims
index 9c3f812..c4ed4c0 100755
--- a/build.nims
+++ b/build.nims
@@ -104,7 +104,7 @@ var
                           "--skipUserCfg:on --colors:off -d:danger " &
                           "--panics:off --mm:orc -d:useMalloc --checks:off " &
                           "-d:ssl --cincludes:extras --opt:speed --nimcache:.cache --passL:'-pthread' " & 
-                          "--path:src "
+                          "--path:src --passC:\"-Wno-error=incompatible-pointer-types\""
     CONFIG              ="@full"
 
     ARGS: seq[string]   = @[] 
